@@ -2,7 +2,7 @@
 # SPDX-License-Identifier: MIT
 
 
-# Zanna and Bolton 2020: https://doi.org/10.1029/2020GL088376
+"""Parameterization as in `Zanna and Bolton (2020) <https://doi.org/10.1029/2020GL088376>`__."""  # noqa: E501
 
 
 __all__ = [
@@ -13,12 +13,29 @@ __all__ = [
 
 
 import functools
-from . import _defs, _parametrized_model
+from . import _defs, _parameterized_model
 from .. import state as _state
 
 
-def apply_parameterization(model, kappa=-46761284):
-    return _parametrized_model.ParametrizedModel(
+def apply_parameterization(model, *, kappa=-46761284):
+    r"""Apply the Zanna-Bolton parameterization to `model`.
+
+    See also: :class:`pyqg.parameterizations.ZannaBolton2020`
+
+    Parameters
+    ----------
+    model
+        The inner model to wrap in the parameterization.
+
+    kappa : float, optional
+        Scaling constant with units :math:`\mathrm{m}^{-2}`.
+
+    Returns
+    -------
+    ParameterizedModel
+        `model` wrapped in the parameterization.
+    """
+    return _parameterized_model.ParameterizedModel(
         model=model,
         param_func=functools.partial(param_func, kappa=kappa),
         init_param_aux_func=init_param_aux_func,
@@ -26,7 +43,7 @@ def apply_parameterization(model, kappa=-46761284):
 
 
 @_defs.uv_parameterization
-def param_func(state, param_aux, model, kappa=-46761284):
+def param_func(state, param_aux, model, *, kappa=-46761284):
     full_state = model.get_full_state(state)
     uh = full_state.uh
     vh = full_state.vh
